mot.optimize package
====================

Submodules
----------

mot.optimize.base module
------------------------

.. automodule:: mot.optimize.base
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: mot.optimize
    :members:
    :undoc-members:
    :show-inheritance:
